#
# spec file for package python-rollbar
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-rollbar
Version:        1.3.0
Release:        1.1
Summary:        Report exceptions, errors, and log messages to Rollbar
License:        MIT
URL:            https://github.com/rollbar/pyrollbar
Source:         https://github.com/rollbar/pyrollbar/archive/v%{version}.tar.gz
BuildRequires:  %{python_module WebOb}
BuildRequires:  %{python_module blinker}
BuildRequires:  %{python_module httpx}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 0.12.1}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-requests >= 0.12.1
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Send messages and exceptions with arbitrary context, get back aggregates, and debug production issues quickly.

%prep
%autosetup -p1 -n pyrollbar-%{version}

%build
%pyproject_wheel

%install
%pyproject_install

%python_clone -a %{buildroot}%{_bindir}/rollbar
%python_expand %fdupes %{buildroot}%{$python_sitelib}

#Examples not needed in the package
%python_expand rm -rf %{buildroot}%{$python_sitelib}/rollbar/examples

%check
%pytest -k 'not (test_shorten_array or test_encode_empty_tuple)'

%post
%python_install_alternative rollbar

%postun
%python_uninstall_alternative rollbar

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/rollbar
%{python_sitelib}/rollbar
%{python_sitelib}/rollbar-%{version}*-info

%changelog
* Wed Apr 30 2025 Felix Stegmeier <felix.stegmeier@suse.com>
- Update to 1.3.0
  * Added support for classes to define the method __rollbar_repr__ to control how objects are serialized by @danielmorell in #479
  * Added support for Python 3.13 by @danielmorell in #477
  * Removed support for Python 3.6 by @danielmorell in #480
  * Updated framework versions tested against by @danielmorell in #480
- Update to 1.2.0
  * Added support for custom payload transforms by @danielmorell in #470
  * Added custom data to the message body by @waltjones in #473
  * Added support for host override setting by @danielmorell in #468
  * Fixed RollbarHandler reconfigures root logger by @ilkecan in #463
  * Fixed include_request_body setting not checked for various frameworks by @danielmorell in #469
  * Fixed namedtuple fields not being scrubbed by @danielmorell in #474
- Update to 1.1.2
  * Added support for custom payload transforms by @danielmorell in #470
  * Added custom data to the message body by @waltjones in #473
  * Added support for host override setting by @danielmorell in #468
  * Fixed RollbarHandler reconfigures root logger by @ilkecan in #463
  * Fixed include_request_body setting not checked for various frameworks by @danielmorell in #469
  * Fixed namedtuple fields not being scrubbed by @danielmorell in #474
- Update to 1.1.1
  * Added support for custom payload transforms by @danielmorell in #470
  * Added custom data to the message body by @waltjones in #473
  * Added support for host override setting by @danielmorell in #468
  * Fixed RollbarHandler reconfigures root logger by @ilkecan in #463
  * Fixed include_request_body setting not checked for various frameworks by @danielmorell in #469
  * Fixed namedtuple fields not being scrubbed by @danielmorell in #474
- Update to 1.1.0
  * Support for Python 3.12
  * Support for pathlib.Path()
  * Updated supported/tested frameworks and modernized tests and packaging by @danielmorell in #455
  * Fixed #398 FastAPI integration fails if docs are disabled by @danielmorell in #459
  * Added support pathlib.Path() objects by @singingwolfboy in $450
  * Added support for Python 3.12 by @danielmorell in #460
  * Changed the ShortenerTransform to use breadth first traversal by @danielmorell in #461
  * Fixed shortener multi level shortening by @danielmorell and @pawelsz-rb. See #449
* Mon Jan 29 2024 pgajdos@suse.com
- python-six is not required
* Fri Jan 12 2024 Dirk Müller <dmueller@suse.com>
- update to 1.0.0:
  * Some of the major work has been on making performance
    improvements to the more data intensive parts of the package.
    There should be some improvements across the board, however
    some exciting new performance features include:
  * A new HTTP transfer mechanism that uses a pool of background
    worker threads to transmit logs and reports to the Rollbar
    system. You can enable it with the following...
  * Removed Python 2
  * Fixed handling `sensitive_post_parameters` decorator in
    Django
  * Fixed Werkzeug DeprecationWarning of `BaseRequest`
  * Fixed missing locals shortening on items with "trace_chain"
    instead of "trace"
  * Fixed FastAPI version comparison
  * Fixed #436 `WSGIRequest` has no attribute
    `sensitive_post_parameters`.
  * Added new `thread_pool` handler
  * Added Rollbar branding to the readme
  * Added batched transform to increase sanitization and
    serialization performance
- drop python-rollbar-no-unittest2.patch (upstream)
* Mon Feb 20 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to 0.16.3:
  * Pinned Python 2 CI tests to legacy version of dependencies. See #408
  * Add PyPI badge for supported Python versions. See #408
  * Add Django 4.0+ compatibility. See #408
  * Update PR template. See #408
  * SC-95272: Remove support for Python 3.3. See #408
- Disable broken tests in python 3.11, test_encode_empty_tuple
* Mon Jan 24 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.16.2:
  * Fix building person data in Django. See #385
  * Fix circular error logging for non-HTTP events in Starlette. See #390
  * Fix Python 3.4 builds. See #389
  * Add support for FastAPI framework. See #373
  * Add support for Starlette framework. See #373
  * Add support for ASGI-compliant frameworks. See #373
  * Add support for HTTPX async handler. See #373
  * Add new honored values of rollbar.SETTINGS['handler']: default, async
    and httpx. See #373
  * Add support for async report_exc_info and report_message. See #373
  * Collect user IP from X-Forwarded-For, fall back to X-Real-Ip. See #370
  * Improve examples. See #368
  * Fix Python 3.3 builds. See #374
  * Fix Flask 0.x builds. See #376
- Add httpx to BuildRequires
- Refresh python-rollbar-no-unittest2.patch
* Wed Aug  5 2020 Matej Cepl <mcepl@suse.com>
- Replace self.assertRegex with six.assertRegex in
  python-rollbar-no-unittest2.patch to finally unrequire
  unittest2 (gh#rollbar/pyrollbar#340).
- Update the patch according to the pending pull request
  gh#rollbar/pyrollbar#346.
* Sat Jul 18 2020 Matej Cepl <mcepl@suse.com>
- Upstream doesn't care about unittest2 at all
  (gh#rollbar/pyrollbar#340), we can just ignore it. Adjust
  python-rollbar-no-unittest2.patch accordingly.
* Wed Jun  3 2020 pgajdos@suse.com
- use %%pytest macro
- remove dependency on unittest2 for python3
- added patches
  https://github.com/rollbar/pyrollbar/pull/340
  + python-rollbar-no-unittest2.patch
* Tue May 19 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Wed Apr 15 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.15.0
  * Prevent recursive re-raising
  * Correctly apply logger formatting
  * Fix deprecation warnings
* Tue Mar 26 2019 pgajdos@suse.com
- require python-setuptools
* Mon Mar 25 2019 pgajdos@suse.com
- version update to 0.14.7
  * Create the configuration options, `capture_username`
    and `capture_email`.
  * Create the configuration option `capture_ip`.
  * Fix `request.files_keys` for Flask
  * If you call `init` multiple times we will update the settings
    at each call.
  * see CHANGELOG.md for details
* Wed Dec 13 2017 tchvatal@suse.com
- Add python-rpm-macros to buildrequires
* Wed Dec 13 2017 tchvatal@suse.com
- Switch to github url to contain license
- Distribute license
- Switch to singlespec
- Enable tests
- Add all missing test and runtime dependencies
* Mon Dec  4 2017 tampakrap@opensuse.org
- Initial package
